/*
 ************************************************************************
 *
 * Copyright (c) 2009 University of Massachusetts, Amherst
 * 
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and/or hardware specification (the "Work") to
 * deal in the Work without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Work, and to permit persons to
 * whom the Work is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Work.
 *
 * THE WORK IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS
 * IN THE WORK.
 *
 ************************************************************************
 *
 * This is a simple XML-RPC server that executes on the DOME Portal system.
 *
 */

import org.apache.xmlrpc.webserver.WebServer;
import org.apache.xmlrpc.server.PropertyHandlerMapping;
import org.apache.xmlrpc.server.XmlRpcServerConfigImpl;
import org.apache.xmlrpc.server.XmlRpcServer;

public class DomeXmlRpcServer {
	
	private static final String handlerName = "DomePortal";
	private static final int defaultPort = 9237;
	private static int port = defaultPort;

	/**
	 * @param args - Arguments passed to this program.
	 */
	public static void main(String[] args) {
		// Parse the command line arguments.
		parseArgs(args);
		try {
			// Set up the "web server" for handling XML-RPC messages. 
			WebServer webServer = new WebServer(port);
			XmlRpcServer rpcServer = webServer.getXmlRpcServer();
			PropertyHandlerMapping phm = new PropertyHandlerMapping();
			DomeMethods methods = new DomeMethods();
			phm.addHandler(handlerName, methods.getClass());
			rpcServer.setHandlerMapping(phm);
			XmlRpcServerConfigImpl serverConfig = (XmlRpcServerConfigImpl) rpcServer.getConfig();
			serverConfig.setEnabledForExceptions(true);
			serverConfig.setContentLengthOptional(false);
			// Start a listening thread (listen forever).
			webServer.start();
		} catch (Exception e) {
			System.err.println("Exception creating servlet: " + e);
			System.exit(1);
		}
	}
	
	/**
	 * Parses the command line arguments.
	 * 
	 * @param args - Arguments passed to this program.
	 */
	private static void parseArgs(String[] args) {
		int indx = 0;
		while (indx < args.length) {
			String opt = args[indx];
			// Port option: -p, --port
			if (opt.equals("-p") || opt.equals("--port")) {
				if (++indx >= args.length) {
					fatal("Option " + opt + ": expected port");
				}
				try {
					port = new Integer(args[indx]);
				} catch (NumberFormatException e) {
					fatal("Invalid port: " + args[indx]);
				}
			// Help option: -h, --help, -?
			} else if (opt.equals("-h") || opt.equals("--help") || opt.equals("-?")) {
				help();
				System.exit(0);
			} else {
				fatal("Invalid option: " + opt);
			}
			indx++;
		}
	}
	
	/**
	 * Prints simple help text.
	 */
	private static void help() {
		System.out.println("Syntax: DomeXmlRpcServer [-p port | --port port]");
		System.out.println(
			"   -p, --port: Port to listen on. Default is " +  defaultPort + ".");
	}
	
	/**
	 * Prints an error message and exits the program.
	 * 
	 * @param msg - Message to print to stderr.
	 */
	private static void fatal(String msg) {
		System.err.println(msg);
		System.exit(1);
	}

}
