/*
 * Copyright (C) 2004-2007 Duke University. This software is distributed under
 * the terms of the Eclipse Public License Version 1.0 found in
 * the file named LICENSE.Eclipse, which was shipped with this distribution.
 * Any use, reproduction or distribution of this software constitutes
 * the recipient's acceptance of the Eclipse license terms.
 * This notice and the full text of the license must be included with any
 * distribution of this software.
 */

package orca.controllers.dieselnet;

import orca.cod.api.ICodSlice;

import orca.manage.container.Manager;
import orca.manage.extensions.api.IExtensionsContainerManager;
import orca.manage.extensions.api.ManagerObject;
import orca.manage.extensions.api.PortalPluginDescriptor;
import orca.manage.extensions.standard.Converter;
import orca.manage.extensions.standard.controllers.ControllerFactory;

import orca.shirako.api.IActor;
import orca.shirako.api.IServiceManager;
import orca.shirako.kernel.CodClientSliceFactory;

import java.util.Properties;

public class DieselnetControllerFactory implements ControllerFactory {
	public static final String PropertySliceName = "sliceName";
	protected IActor actor;
	protected Manager manager;
	protected DieselnetController cont;
	protected DieselnetManagerObject dieselnetManagerObject;
	protected PortalPluginDescriptor desc;
	protected String sliceName = "dieselnet";

	public void configure(Properties p) throws Exception {
		process(p);
	}

	public void configure(String p) throws Exception {
		Properties pp = Converter.decodeProperties(p);
		process(pp);
	}

	public void create(IExtensionsContainerManager manager) throws Exception {
		this.manager = (Manager) manager;

		if (!(actor instanceof IServiceManager)) {
			throw new Exception("Invalid actor type");
		}

		if (sliceName == null) {
			throw new Exception("Missing slice name");
		}

		ICodSlice slice = (ICodSlice) CodClientSliceFactory.getInstance()
				.create(sliceName);
		actor.registerSlice(slice);

		cont = new DieselnetController();
		cont.setActor(actor);
		cont.setSlice(slice);
		cont.initialize();
		// attach the controller to the slice
		slice.setController(cont);

		dieselnetManagerObject = new DieselnetManagerObject(cont, actor);
		dieselnetManagerObject.initialize(manager);

		desc = new PortalPluginDescriptor();
		desc.setRootClassName(DieselnetPortalPlugin.class.getCanonicalName());
		desc.setManagerKey(dieselnetManagerObject.getID().toString());
		desc.setKey(dieselnetManagerObject.getID().toString());
		desc.setActorName(actor.getName());
		desc.setSliceName(sliceName);
		desc.setPackageId(DieselnetConstants.PackageId);
	}

	public ManagerObject getManager() {
		return dieselnetManagerObject;
	}

	public Object getObject() {
		return cont;
	}

	public PortalPluginDescriptor getRoot() {
		return desc;
	}

	protected void process(Properties p) throws Exception {
		if (p.getProperty(PropertySliceName) != null) {
			sliceName = p.getProperty(PropertySliceName);
		}
	}

	public void setActor(IActor actor) {
		this.actor = actor;
	}
}
