/*
 ************************************************************************
 *
 * Copyright (c) 2009 University of Massachusetts, Amherst
 * 
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and/or hardware specification (the "Work") to
 * deal in the Work without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Work, and to permit persons to
 * whom the Work is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Work.
 *
 * THE WORK IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS
 * IN THE WORK.
 *
 ************************************************************************
 *
 * This is a helper class for building the objects needed to execute an
 * XML-RPC request.
 */

package orca.handlers.dieselnet;

import java.net.URL;
import org.apache.xmlrpc.client.XmlRpcClient;
import org.apache.xmlrpc.client.XmlRpcClientConfigImpl;

class DieselnetClient {
	
	/**
	 * Sets up the XmlRpcClient object based on the supplied URL.
	 * 
	 * @param serverURL - URL of the XML-RPC server, e.g.
	 *    http://localhost:8090/dome.
	 * @return The XmlRpcClient object for sending requests.
	 */
	static protected XmlRpcClient initialize(String serverURL) {
		try {
			XmlRpcClientConfigImpl config = new XmlRpcClientConfigImpl();
		    config.setServerURL(new URL(serverURL));
		    XmlRpcClient client = new XmlRpcClient();
		    client.setConfig(config);
		    return client;
		} catch (Exception e) {
			return null;
		}
	}
	
	/**
	 * Creates an array for storing parameters that will be passed to
	 * the XML-RPC call.
	 * 
	 * @param size - Size of the array to be created, i.e. number of
	 *    parameters.
	 * @return - The created array.
	 */
	static protected Object[] createParams(int size) {
		return new Object[size];
	}
	
	/**
	 * Inserts a parameter of type integer into the array.
	 * 
	 * @param parms - Array parameter as generated by createParms().
	 * @param val - The integer value to be stored.
	 * @param index - Index into the array where the value is to be
	 *    stored (0 is the first parameter in the list).
	 */
	static protected void addParam(Object[] parms, int val, int index) {
		parms[index] = new Integer(val);
	}
	
	/**
	 * Inserts a parameter of type long into the array.
	 * 
	 * @param parms - Array parameter as generated by createParms().
	 * @param val - The long value to be stored.
	 * @param index - Index into the array where the value is to be
	 *    stored (0 is the first parameter in the list).
	 */
	static protected void addParam(Object[] parms, long val, int index) {
		parms[index] = new Long(val);
	}
	
	/**
	 * Inserts a parameter of type string into the array.
	 * 
	 * @param parms - Array parameter as generated by createParms().
	 * @param val - The string to be stored.
	 * @param index - Index into the array where the string is to be
	 *    stored (0 is the first parameter in the list).
	 */
	static protected void addParam(Object[] parms, String val, int index) {
		parms[index] = new String(val);
	}

}
