/*
 ************************************************************************
 *
 * Copyright (c) 2009 University of Massachusetts, Amherst
 * 
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and/or hardware specification (the "Work") to
 * deal in the Work without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute,
 * sublicense, and/or sell copies of the Work, and to permit persons to
 * whom the Work is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Work.
 *
 * THE WORK IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE WORK OR THE USE OR OTHER DEALINGS
 * IN THE WORK.
 *
 ************************************************************************
 *
 * Executes the XML-RPC leave call to the DOME portal.
 *
 */

package orca.handlers.dieselnet;

import org.apache.tools.ant.BuildException;
import org.apache.xmlrpc.client.XmlRpcClient;

public class DieselnetTaskLeave extends DieselnetTask {
	
private static final String leaveMethod = "DomePortal.orcaLeave";
	
	/**
	 * Invokes the XMl-RPC leave call to the DOME portal.
	 * 
	 * @return Value that will be returned by the task.
	 */
	protected int doExecute() throws BuildException {
		// We know that the experiment, instance and server have been
		// specified. Make certain we have a ticket id.
		if (domeTicketId == null) {
			throw new BuildException("Property required by DOME Leave is not set ");
		}
		// Set up the XML-RPC client call:
		//    orcaLeave(experiment, instance, ticketid)
		try {
			XmlRpcClient client = DieselnetClient.initialize(domeServer);
			if (client == null) {
				log("Failed to set up the XML-RPC client");
				return EXITRPCCLIENT;
			}
			Object[] parms = DieselnetClient.createParams(3);
			DieselnetClient.addParam(parms, domeExperiment, 0);
			DieselnetClient.addParam(parms, domeInstance, 1);
			DieselnetClient.addParam(parms, domeTicketId, 2);
			// Execute the XML-RPC call.
			int rtrn = (Integer)client.execute(leaveMethod, parms);
			if (rtrn != 0) {
				log("Call to orcaLeave() failed: " + rtrn);
				return EXITRPCFAILED;
			}
			log("Leave succeeded");
			return 0;
		} catch (Exception e) {
			log("Exception attempting leave:" + e);
			return EXITRPCCLIENT;
		}
	}
}
