/*
 * Copyright (C) 2004-2007 Duke University. This software is distributed under
 * the terms of the Eclipse Public License Version 1.0 found in
 * the file named LICENSE.Eclipse, which was shipped with this distribution.
 * Any use, reproduction or distribution of this software constitutes
 * the recipient's acceptance of the Eclipse license terms.
 * This notice and the full text of the license must be included with any
 * distribution of this software.
 */


/**
 * This source is a placeholder.
 */


package orca.controllers.dieselnet;

import orca.shirako.container.ContainerManager;

import orca.controllers.dieselnet.DieselnetConstants;
import orca.controllers.dieselnet.DieselnetController;
import orca.controllers.dieselnet.DieselnetControllerFactory;

import orca.manage.container.Manager;
import orca.manage.extensions.api.ApiConverter;
import orca.manage.extensions.api.beans.PropertiesMng;
import orca.manage.extensions.api.beans.ResultMng;
import orca.manage.extensions.standard.actors.CodServiceManagerManagerObject;
import orca.manage.extensions.standard.beans.PluginCreateMng;

import orca.shirako.api.IActor;
import orca.shirako.api.IServiceManager;
import orca.shirako.registry.ActorRegistry;

import orca.tests.core.ShirakoTest;

import java.util.Properties;


public class DieselnetTest extends ShirakoTest
{
    public static final String ActorName = "service";
    public static final String DieselnetPackageId = DieselnetConstants.PackageId.toString();
    public static final String DieselnetControllerPluginId = "1";
    public static final String DieselnetSliceName = "dieselnet";

    public static void main(String[] args) throws Exception
    {
        if (args.length > 0) {
            ShirakoTest test = new DieselnetTest(args);
            test.run();
        } else {
            System.out.println("Insufficient arguments");
        }
    }

    public DieselnetTest(String[] args)
    {
        super(args);
    }

    protected DieselnetController getDieselnetController()
    {
        IServiceManager actor = (IServiceManager) ActorRegistry.getActor(ActorName);

        return (DieselnetController) actor.getControllers().get(0);
    }

    @Override
    protected void runTest()
    {
        try {
            startDieselnet();

            getDieselnetController();

            System.out.println("Controller was created");
            
            // We don't do anything!

        } catch (Exception e) {
            e.printStackTrace();
            System.out.println("Test failed");
            System.exit(-1);
        }

        System.out.println("Test successful");
        System.exit(0);
    }

    /**
     * Starts the DieselNet controller
     * @throws Exception
     */
    protected void startDieselnet() throws Exception
    {
        IActor actor = ActorRegistry.getActor(ActorName);

        if (actor == null) {
            throw new RuntimeException("Actor: " + ActorName + " does not exist in this container");
        }

        // the manager object gives us access to the management interface
        Manager manager = (Manager) ContainerManager.getInstance();

        // to create the controller we need to create a plugin descriptor
        PluginCreateMng plugin = new PluginCreateMng();
        // set the package and plugin id of the controller we are trying to
        // create
        plugin.setPackageId(DieselnetPackageId);
        plugin.setId(DieselnetControllerPluginId);

        // the controller may require properties. set them here
        Properties p = new Properties();
        // set whatever properties are required for the instantiation of the
        // controller
        p.setProperty(DieselnetControllerFactory.PropertySliceName, DieselnetSliceName);

        // convert to propertiesmng
        PropertiesMng props = ApiConverter.fill(p);
        // attach the configuration properties
        plugin.setConfigurationProperties(props);

        CodServiceManagerManagerObject man = (CodServiceManagerManagerObject) manager.getManagerObjectManager()
                                                                                     .getManagerObject(
            actor.getGuid());
        ResultMng result = man.addApplication(plugin);

        if (result.getCode() != 0) {
            throw new Exception("Cannot instantiate controller. Error code: " + result.getCode());
        }
    }
}
